// most code is just needed to make sure this only works when all relevant pairs have cycled
(function deactivateWorstPair(data) {
    // function sets STOP_AFTER_SELL for pairs that have hit an exit filter, also makes sure there's always one pair without STOP_AFTER_SELL
    const base = data.pairName.split('-')[0];
    let configPairCount = 0;
    let sameBasePairs = [];
    let maxSameBase = 0;
    const timeNow = Date.now()
    const oneHour = 3600000
    const checkRemove = function (trendData, pair) {
        const overrides = data.config.pairs.binance[pair].override
        const volatilityMode = overrides?.VOLATILITY_MODE || false
        const taMode = overrides?.TA_MODE || false
        const pullbackMode = overrides?.PULLBACK_MODE || false
        const useCustomTradingRangeMode = overrides?.CUSTOM_TRADING_RANGE_MODE || false

        if (volatilityMode) {
            if (trendData?.endBullish4hLastHit > trendData?.volatilityBuy4hLastHit || trendData?.volatiltyExit4h > trendData?.volatilityBuy4h || trendData?.volatilityBuy4hLastHit === trendData?.volatiltyExit4h) {
                return true
            }
            // this handles a case where data got lost after deleting/corrupting pair json
            else if (trendData?.volatilityBuy4h === 0 && overrides?.BAG_SIZE === 'none') {
                return true
            }
        }
        else if (taMode) {
            if (trendData?.taFractalsExitLastHit > trendData?.taFractalsLastHit || trendData?.endBullish4hLastHit > trendData?.taFractalsLastHit || trendData?.taFractalsLastHit === trendData?.taFractalsExitLastHit) {
                return true
            }
            // this handles a case where data got lost after deleting/corrupting pair json
            else if (trendData?.taFractals === 0 && overrides?.BAG_SIZE === 'none') {
                return true
            }
        }
        else if (pullbackMode) {
            if (!trendData.pullback4h) {
                return true
            }
            // this handles a case where data got lost after deleting/corrupting pair json
            else if (trendData?.pullback4h === 0 && overrides?.BAG_SIZE === 'none') {
                return true
            }
            else if (timeNow - trendData?.pullback4hLastHit > oneHour * 2 && overrides?.BAG_SIZE === 'none') {
                return true
            }
        }
        else if (useCustomTradingRangeMode) {
            //console.log('timenow', timeNow, 'result', timeNow - (overrides?.timestamp * 1000), 'target', oneHour / 2)
            if (timeNow - (overrides?.timestamp * 1000) > oneHour / 2 && overrides?.BAG_SIZE === 'none') {
                return true
            }
        }
        
    } 
    Object.keys(data.config.pairs.binance).forEach((pair => {
        if (pair.split('-')[0] === base) {
            configPairCount++;
            sameBasePairs.push(pair)
        }
        if (maxSameBase === 0) {
            maxSameBase = parseFloat(data.config.pairs.binance[pair].override.MAX_PAIR_PER_BASE)
        }
    }));
    let positions = [];
    let activePairCount = 0;
    let pairsToRemove = []
    let pairsAlreadyMarkedForRemoval = []
    sameBasePairs.forEach((pair => {
        if (Object.keys(data.pairVariables.binance).indexOf(pair) > -1) {
            if (parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.BAG_SIZE) > 0) {
                positions.push(parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.BAG_SIZE));
            } else if (data.pairVariables.binance?.[pair]?.newOverrides?.BAG_SIZE === 'none') {
                positions.push(0);
            }
            // count pairs as active when they have status active and have traded long enough to gather ranking stats OR when they have just been panic sold
            if (data.pairVariables.binance?.[pair]?.newOverrides?.STATUS === 'active') {
                activePairCount++;
            }
            if (data.pairVariables.binance?.[pair]?.newOverrides?.STOP_AFTER_SELL) {
                pairsAlreadyMarkedForRemoval.push(pair)
            }
            if (checkRemove(data.pairVariables.binance?.[pair]?.newOverrides?.trendData, pair) && data.pairVariables.binance?.[pair]?.newOverrides?.STOP_AFTER_SELL === false) {
                pairsToRemove.push(pair)
            }

        }
    }));

    let pairsNotMarkedForRemoval = sameBasePairs.filter(pair => [...pairsToRemove, ...pairsAlreadyMarkedForRemoval].indexOf(pair) < 0)
    //console.log('pairs marked for removal', pairsToRemove, ' pairs not marked for removal', pairsNotMarkedForRemoval)
    if (activePairCount >= 2 && data.config.pairs.binance[data.pairName].override?.BUY_METHOD === 'gain' && data.config.pairs.binance[data.pairName].override?.PANIC_SELL && data.config.pairs.binance[data.pairName].override?.BAG_VALUE === 'none'){
        // catch a case where pair should have been removed already
        return true
    }
    else if (positions.length === configPairCount && activePairCount >= 2 && pairsToRemove.indexOf(data.pairName) === 0 && activePairCount - pairsAlreadyMarkedForRemoval.length >= 1) {
        // set STOP_AFTER_SELL true for one pair at a time
        return true;
    }
    else if (positions.length === configPairCount && activePairCount > maxSameBase && pairsNotMarkedForRemoval.length > 1 && pairsNotMarkedForRemoval.indexOf(data.pairName) === 0) {
        // set STOP_AFTER_SELL true for one pair, in case active pair count exceeds allowed maximum
        return true;
    }
    else {
        return false;
    }
})(this)