(function handleOverrides(data) {
	// function only considers other pairs with same base currency as the function runs for
	const base = data.pairName.split('-')[0];

	// default set of overrides
	let overrides = {
		TRADING_LIMIT: data.pair.whatstrat.TRADING_LIMIT,
		STOP_AFTER_SELL: data.pair.whatstrat.STOP_AFTER_SELL,
		ALLOW_SL: data.pair.whatstrat.ALLOW_SL || false,
		BUY_ENABLED: data.pair.whatstrat.BUY_ENABLED,
		BUY_METHOD: data.pair.whatstrat.BUY_METHOD || 'stepgridhybrid',
		SELL_METHOD: data.pair.whatstrat.SELL_METHOD || 'stepgridhybrid',
		PANIC_SELL: data.pair.whatstrat.PANIC_SELL || false,
		BAG_SIZE: data.pair.whatstrat.BAG_SIZE,
		BAG_VALUE: data.pair.whatstrat.BAG_VALUE || 'none',
		REMOVE: data.pair.whatstrat.REMOVE,
		RANKING_RESULT: data.pair.whatstrat.RANKING_RESULT,
		STATUS: data.pair.whatstrat.STATUS || 'new',
		MIN_VOLUME_TO_SELL: base === 'USDT' || base === 'BUSD' || base === 'USDC' || base === 'USD' || base === 'EUR' ? 10 : base === 'BTC' ? 0.0002 : base === 'ETH' ? 0.005 : base === 'BNB' ? 0.05 : 0.0002,
		trendData: data.pair.trendCheck || {},
		isTrailing: false,
	};

	// variable declarations
	const bid = data.pair.Bid;
	const quoteBalance = data.pair.quoteBalance;
	const baseBalance = data.pair.baseBalance;
	const mvts = parseFloat(overrides.MIN_VOLUME_TO_SELL);
	const ABP = parseFloat(data.pair.ABP);
	const keepQuote = parseFloat(data.pair.whatstrat.KEEP_QUOTE);
	const baseReservePct = parseFloat(data.pair.whatstrat.BASE_RESERVE_PCT) / 100 || 0;
	const notEnoughCandles = typeof data.pair.candlesclose === 'undefined' ? true : data.pair.candlesclose.length < 80;
	const maxSameBase = parseFloat(data.pair.whatstrat.MAX_PAIR_PER_BASE);
	const totalBaseValue = parseFloat(data.pair.whatstrat.TOTAL_BASE_VALUE) - (parseFloat(data.pair.whatstrat.TOTAL_BASE_VALUE) * baseReservePct);
	const rankingResult = parseFloat(overrides.RANKING_RESULT);
	const tl = parseFloat(overrides.TRADING_LIMIT);
	const status = overrides.STATUS;
	const TLRatio = parseFloat(data.pair.whatstrat?.[`TL_RATIO_${base}`]) || parseFloat(data.pair.whatstrat?.TL_RATIO) || 40;
	const reserveThreshold = (parseFloat(data.pair.whatstrat.TOTAL_BASE_VALUE) * baseReservePct)
	const needFunds = (quoteBalance > 0 && baseBalance >= 0 && baseBalance < tl * 2) || (quoteBalance > 0 && baseBalance >= 0 && baseBalance < reserveThreshold)
	const lastOrderType = data.pair?.orders?.[0]?.type
	const orderCount = data.pair?.orders.length
	let worstBagSameBase = ''
	let worstBagSameBaseUpnl = 0

	// save trailing status, to prevent adding pairs while a pair is trailing
	if (data.pair?.sellTrailingTarget > 0 || data.pair?.buyTrailingTarget > 0){
		overrides.isTrailing = true
	}
	else {
		overrides.isTrailing = false
	}

	// store bag with worst drawdown to remove in case the bot runs out of available funds
	Object.keys(data.config.pairs.binance).forEach((pair => {
		if (pair.split('-')[0] === base) {
			if (overrides.BAG_SIZE !== 'none' && overrides.BAG_VALUE !== 'none') {
				const drawdown = parseFloat(overrides.BAG_SIZE) - parseFloat(overrides.BAG_VALUE)
				if (drawdown > worstBagSameBaseUpnl) {
					worstBagSameBase = pair
					worstBagSameBaseUpnl = drawdown
				}
			}
		}
	}));

	function updateIfEnoughDifference(oldValue, newValue) {
		if (typeof oldValue == 'string' && typeof newValue != 'string') {
			return newValue
		}
		else if (typeof oldValue != 'string' && typeof newValue == 'string') {
			return newValue
		}
		const minimumDifference = oldValue * 0.005
		let difference;
		if (oldValue > newValue) {
			difference = oldValue - newValue;
		} else {
			difference = newValue - oldValue;
		}
		if (difference > minimumDifference) {
			return newValue;
		}
		else {
			return oldValue;
		}
	}
	

	// handle pair status changes
	function setStatus() {
		let activePairsSameBase = 0;
		Object.keys(data.config.pairs.binance).forEach((pair => {
			if (pair.split('-')[0] === base) {
				if (data.config.pairs.binance[pair].override.STATUS === 'active') {
					activePairsSameBase++;
				}
			}
		}));
		const freeSlots = maxSameBase - activePairsSameBase;

		// handle new pairs
		if (status === 'new' && rankingResult != -1 && freeSlots > 0) {
			if (rankingResult === -2) {
				overrides.STATUS = 'inactive';
				overrides.REMOVE = true;
			}
			else if (rankingResult <= freeSlots) {
				overrides.STATUS = 'active';
				// when function returns true, newly activated pairs get their trading limit set
				return true;
			} else {
				overrides.STATUS = 'inactive';
				overrides.REMOVE = true;
			}
		}
		else if (status === 'new' && freeSlots < 1) {
			overrides.STATUS = 'inactive';
			overrides.REMOVE = true;
		}
		// handle active pairs that are about to get removed
		if (status === 'active' && overrides.BAG_SIZE === 'none' && (lastOrderType === 'sell' || orderCount < 1) && overrides.STOP_AFTER_SELL) {
			overrides.STATUS = 'inactive';
			overrides.REMOVE = true;
			overrides.BUY_ENABLED = false;
		}
		else if (needFunds && status === 'active' && overrides.ALLOW_SL && data.pairName === worstBagSameBase) {
			// case: bot is out of funds, sell worst performing bag
			overrides.BUY_METHOD = 'gain'
			overrides.SELL_METHOD = 'gain'
			overrides.PANIC_SELL = true
			overrides.STOP_AFTER_SELL = true
		}
		//  handle pairs with incorrect status, which can happen if balances are briefly unavailable
		else if (status === 'inactive' && !overrides.REMOVE) {
			// handles case where remove is reset outside this function, when it was the last remaining pair at some point
			overrides.REMOVE = true;
		}
		else if (status === 'inactive' && overrides.REMOVE && overrides.BAG_SIZE !== 'none') {
			// reset to correct status
			overrides.STATUS = 'active';
			overrides.REMOVE = false;
			overrides.BUY_ENABLED = true;
		}
	}

	// balance tracking
	function setBagSize() {
		if (overrides.BAG_SIZE !== 'none') {
			if (lastOrderType === 'sell' && (quoteBalance - keepQuote) * bid < mvts) {
				overrides.BAG_SIZE = 'none';
				overrides.BAG_VALUE = 'none'
			}
			else if ((quoteBalance - keepQuote) * ABP > 0) {
				overrides.BAG_SIZE = updateIfEnoughDifference(overrides.BAG_SIZE, (quoteBalance - keepQuote) * ABP)
				overrides.BAG_VALUE = updateIfEnoughDifference(overrides.BAG_VALUE, (quoteBalance - keepQuote) * bid)
			}
		}
		else if ((quoteBalance - keepQuote) * bid < mvts) {
			overrides.BAG_SIZE = 'none';
			overrides.BAG_VALUE = 'none'
		}
		else {
			if ((quoteBalance - keepQuote) * ABP > 0) {
				overrides.BAG_SIZE = updateIfEnoughDifference(overrides.BAG_SIZE, (quoteBalance - keepQuote) * ABP)
				overrides.BAG_VALUE = updateIfEnoughDifference(overrides.BAG_VALUE, (quoteBalance - keepQuote) * bid)
			}
			else {
				overrides.BAG_SIZE = 'none';
				overrides.BAG_VALUE = 'none'
			}
		}
	}

	// set compounding trading limit
	function setTradingLimit() {
		const tl = (totalBaseValue / maxSameBase) / TLRatio;
		if (tl > mvts) {
			overrides.TRADING_LIMIT = updateIfEnoughDifference(overrides.TRADING_LIMIT, tl.toPrecision(5))
			overrides.BUY_ENABLED = true;
		}
		else {
			overrides.TRADING_LIMIT = mvts * 1.1;
			overrides.BUY_ENABLED = true;
		}
	}

	// update pair bag stats
	setBagSize();

	// return safe set of overrides in case critical data is missing
	if (Object.is(totalBaseValue, NaN) || totalBaseValue === 0 || notEnoughCandles) {
		return overrides;
	}

	// set correct pair status
	if (setStatus() === true) {
		// set new trading limit when pair is newly activated
		setTradingLimit();
	}

	// set new trading limit after selling a bag
	if (overrides.BAG_SIZE === 'none' && overrides.STATUS === 'active' && !overrides.STOP_AFTER_SELL) {
		setTradingLimit()
	}
	// set trading limit if the current one is obviously wrong
	if (overrides.BAG_SIZE !== 'none' && overrides.STATUS === 'active' && tl < mvts) {
		setTradingLimit()
	}

	// save overrides to pairVariables
	return overrides;
})(this)