(function setPullbackMode(data) {
	// function returns boolean for setting initial values for PULLBACK_MODE

    const settingName = 'PULLBACK_MODE'
   
    const checkTrend = function (trendData, pair) {
        let possibleModes = []

		const overrides = data.config.pairs.binance[pair].override
		const useTrendSync = overrides?.TREND_SYNC || false;
        const volatilityMode = overrides?.VOLATILITY_MODE || false;
		const pullbackMode = overrides?.PULLBACK_MODE || false;
        const taMode = overrides?.TA_MODE || false;
		const useCustomTradingRangeMode = overrides?.CUSTOM_TRADING_RANGE_MODE || false;
		const testActiveCustomRangePairs = (element) => data.config.pairs.binance[element]?.override?.STATUS === 'active' && data.config.pairs.binance[element]?.override?.CUSTOM_TRADING_RANGE_MODE && data.config.pairs.binance[element]?.override?.BAG_SIZE !== 'none'
		const hasActiveCustomRangePairs = Object.keys(data.config.pairs.binance).some(testActiveCustomRangePairs)

        if (overrides?.STATUS === 'new') {
            if (volatilityMode && trendData.structure && trendData.volatilityBuy4h && !trendData.doNotOpen) {
                if (!useTrendSync) {
                    possibleModes.push('VOLATILITY_MODE')
                }
                else if (trendData?.structureSync){
                    possibleModes.push('VOLATILITY_MODE')
                }
            }
            else if (taMode && trendData?.taFractals) {
                if (!useTrendSync) {
                    possibleModes.push('TA_MODE')
                }
                else if (trendData?.structureSync){
                    possibleModes.push('TA_MODE')
                }
            }
            else if (pullbackMode && trendData.pullback4h) {
                if (!useTrendSync) {
                    possibleModes.push('PULLBACK_MODE')
                }
                else if (trendData?.structureSync){
                    possibleModes.push('PULLBACK_MODE')
                }
            }
            else if (useCustomTradingRangeMode && trendData.structure && trendData.structureSync && trendData.tlr > 0.5 && trendData.exitTrail === false && !hasActiveCustomRangePairs) {
                possibleModes.push('CUSTOM_TRADING_RANGE_MODE')
            }

            else {
                // set false when none of the conditions for enabled modes match
                return false
            }
            // set true if settingName is first matching mode
            if (possibleModes.indexOf(settingName) === 0) {
                return true
            }
        }
        else {
            // never change value when pair status is not 'new' anymore
            return overrides?.[settingName] || false
        }  
    }  
	
    return checkTrend(data.pairVariables.binance?.[data.pairName]?.newOverrides?.trendData, data.pairName)

})(this)