const fs = require("fs");
const minify = require("minify");
const options = {
    js: {
        ecma: 5,
        compress: false,
        mangle: false,
        format: { quote_style: 1 },
        keep_fnames: true,
    },
};

// templates for config.js and autoconfig.json
const defaultConfig = JSON.parse(fs.readFileSync("src/config.js"));
const defaultAutoconfig = JSON.parse(fs.readFileSync("src/compounding_auto-pairs/autoconfig.json"));

// definitions for different config builds
const outputVariations = [
    // auto pairs + compounding
    {
        exchange: "ftxus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 3,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftxus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 4,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftxus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 5,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftxus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 6,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftxus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 7,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftxus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 8,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftx",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 3,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftx",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 4,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftx",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 5,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftx",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 6,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftx",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 7,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "ftx",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 8,
        pairExcludes: "MOVE,VOL,OPTIONS,21,22,23,24,25,BULL,BEAR,HEDGE,HALF,PERP",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 2,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-BNB,USDT-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "BUSD-BTC,BUSD-BNB,BUSD-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,BUSD-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "BUSD-BTC,BUSD-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,BUSD-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-BNB,USDT-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD"],
        maxPairPerBase: 3,
        pairExcludes: "BUSD-BTC,UP,DOWN",
        pairIncludes: "BTC-,BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD"],
        maxPairPerBase: 4,
        pairExcludes: "BUSD-BTC,UP,DOWN",
        pairIncludes: "BTC-,BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 4,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-BNB,USDT-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "BUSD-BTC,BUSD-BNB,BUSD-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,BUSD-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "BUSD-BTC,BUSD-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,BUSD-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-BNB,USDT-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD"],
        maxPairPerBase: 3,
        pairExcludes: "BUSD-BTC,UP,DOWN",
        pairIncludes: "BTC-,BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "BUSD"],
        maxPairPerBase: 4,
        pairExcludes: "BUSD-BTC,UP,DOWN",
        pairIncludes: "BTC-,BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 4,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 3,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 4,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "3S,3L,VAI",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-ETH,BTC-ETH,3S,3L,VAI",
        pairIncludes: "BTC-,USDT-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,3S,3L,VAI",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "BTC-ETH,3S,3L,VAI",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 4,
        pairExcludes: "BTC-ETH,3S,3L,VAI",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "USD"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USD-BTC,USD-USDT,UP,DOWN",
        pairIncludes: "BTC-,USDT-,USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USD"],
        maxPairPerBase: 3,
        pairExcludes: "USD-BTC,UP,DOWN",
        pairIncludes: "BTC-,USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USD"],
        maxPairPerBase: 4,
        pairExcludes: "USD-BTC,UP,DOWN",
        pairIncludes: "BTC-,USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT", "USD"],
        maxPairPerBase: 3,
        pairExcludes: "USD-USDT,UP,DOWN",
        pairIncludes: "USDT-,USD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT", "USD"],
        maxPairPerBase: 4,
        pairExcludes: "USD-USDT,UP,DOWN",
        pairIncludes: "USDT-,USD-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-,USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-,USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    /*
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USD"],
        maxPairPerBase: 3,
        pairExcludes: "USD-BTC,UP,DOWN",
        pairIncludes: "BTC-,USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USD"],
        maxPairPerBase: 4,
        pairExcludes: "USD-BTC,UP,DOWN",
        pairIncludes: "BTC-,USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "EUR"],
        maxPairPerBase: 3,
        pairExcludes: "EUR-BTC,UP,DOWN",
        pairIncludes: "BTC-,EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "EUR"],
        maxPairPerBase: 4,
        pairExcludes: "EUR-BTC,UP,DOWN",
        pairIncludes: "BTC-,EUR-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT", "USD"],
        maxPairPerBase: 3,
        pairExcludes: "USD-USDT,UP,DOWN",
        pairIncludes: "USDT-,USD-",
        fees: 0.26,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT", "USD"],
        maxPairPerBase: 4,
        pairExcludes: "USD-USDT,UP,DOWN",
        pairIncludes: "USDT-,USD-",
        fees: 0.26,
    },
    */
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "okex5",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 4,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 3,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 4,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "okgunbot",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "ETH"],
        maxPairPerBase: 4,
        pairExcludes: "BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,ETH-",
        fees: 0.1,
    },
];

void (async function buildAC() {
    // functions to use in autoconfig.json
    // defaults get assigned while looping through output variations
    let handleOverrides
    let deactivateWorstPair
    let rankNewPairs
    let maxPairs
    let setPullbackMode
    let setTaMode
    let setVolatilityMode
    let setUseTlr
    let setDynamicSL
    let setCustomTradingRangeMode
    let setCustomRangeLow
    let setCustomRangeHigh
    let checkFreeSlots
    let dontLetLastPairBeRemoved
    let totalBaseBalance

    // for compounding-auto-pairs
    const handleOverrides_default = " " + (await minify("src/compounding_auto-pairs/handleOverrides.js", options)).slice(0, -1);
    const deactivateWorstPair_default = " " + (await minify("src/compounding_auto-pairs/deactivateWorstPair.js", options)).slice(0, -1);
    const rankNewPairs_default = " " + (await minify("src/compounding_auto-pairs/rankNewPairs.js", options)).slice(0, -1);
    const maxPairs_default = " " + (await minify("src/compounding_auto-pairs/maxPairs.js", options)).slice(0, -1);
    const setPullbackMode_default = " " + (await minify("src/compounding_auto-pairs/setPullbackMode.js", options)).slice(0, -1);
    const setTaMode_default = " " + (await minify("src/compounding_auto-pairs/setTaMode.js", options)).slice(0, -1);
    const setVolatilityMode_default = " " + (await minify("src/compounding_auto-pairs/setVolatilityMode.js", options)).slice(0, -1);
    const setUseTlr_default = " " + (await minify("src/compounding_auto-pairs/setUseTlr.js", options)).slice(0, -1);
    const setDynamicSL_default = " " + (await minify("src/compounding_auto-pairs/setDynamicSL.js", options)).slice(0, -1);
    const setCustomTradingRangeMode_default = " " + (await minify("src/compounding_auto-pairs/setCustomMode.js", options)).slice(0, -1);
    const setCustomRangeLow_default = " " + (await minify("src/compounding_auto-pairs/setCustomLow.js", options)).slice(0, -1);
    const setCustomRangeHigh_default = " " + (await minify("src/compounding_auto-pairs/setCustomHigh.js", options)).slice(0, -1);
    const checkFreeSlots_default = " " + (await minify("src/compounding_auto-pairs/checkFreeSlots.js", options)).slice(0, -1);
    const dontLetLastPairBeRemoved_default = " " + (await minify("src/compounding_auto-pairs/dontLetLastPairBeRemoved.js", options)).slice(0, -1);
    const totalBaseBalance_default = " " + (await minify("src/compounding_auto-pairs/totalBaseBalance.js", options)).slice(0, -1);

    // build configs
    outputVariations.forEach((item) => {
        const modifiedConfig = JSON.parse(JSON.stringify(defaultConfig));
        if (!item.manualPairs && item.compounding) {
            handleOverrides = handleOverrides_default
            deactivateWorstPair = deactivateWorstPair_default
            rankNewPairs = rankNewPairs_default
            maxPairs = maxPairs_default
            setPullbackMode = setPullbackMode_default
            setTaMode = setTaMode_default
            setVolatilityMode = setVolatilityMode_default
            setUseTlr = setUseTlr_default
            setDynamicSL = setDynamicSL_default
            setCustomTradingRangeMode = setCustomTradingRangeMode_default
            setCustomRangeLow = setCustomRangeLow_default
            setCustomRangeHigh = setCustomRangeHigh_default
            checkFreeSlots = checkFreeSlots_default
            dontLetLastPairBeRemoved = dontLetLastPairBeRemoved_default
        }
        totalBaseBalance = totalBaseBalance_default


        const mvtsDefault = "MIN_VOLUME_TO_SELL:base==='USDT'||base==='BUSD'||base==='USDC'||base==='USD'||base==='EUR'?10:base==='BTC'?2e-4:base==='ETH'?.005:base==='BNB'?.05:2e-4"
        const mvtsKraken = "MIN_VOLUME_TO_SELL:base==='USDT'||base==='BUSD'||base==='USDC'||base==='USD'||base==='EUR'?60:base==='BTC'?0.001:base==='ETH'?.005:base==='BNB'?.05:2e-4"
        const compatibleMvts = item.exchange === 'kraken' ? mvtsKraken : mvtsDefault
        const exchangeDir = `build/${item.exchange}`
        const dir = `build/${item.exchange}/${item.maxPairPerBase * item.baseCurrencies.length}pairs_${item.baseCurrencies.join("-")}_${item.compounding && !item.manualPairs ? "compounding_auto-pairs" : null}`;

        if (!fs.existsSync(exchangeDir)) {
            fs.mkdirSync(exchangeDir);
        }
        if (!fs.existsSync(dir)) {
            fs.mkdirSync(dir);
        }

        const exchangeSettings = {
            key: "dum...",
            secret: "dum...",
            masterkey: "dum...",
            mastersecret: "dum...",
            delay: item.exchange === 'kraken' ? 8 : item.exchange === 'kucoin' ? 8 : 0,
            market: "spot",
            isEncrypted: false,
            includeCoins: "",
            filteredBase: "",
            filteredQuote: "",
            autoPairs: false,
            tick_interval: 30,
            tick_time: false,
            TRADING_FEES: item.fees,
        };

        modifiedConfig.exchanges[item.exchange] = exchangeSettings;
        const modifiedAutoconfigTemplate = JSON.parse(JSON.stringify(defaultAutoconfig))

        // include exchange name in job names
        const renameKeys = (keysMap, obj) =>
            Object.keys(obj).reduce(
                (acc, key) => ({
                    ...acc,
                    ...{ [keysMap[key] || key]: obj[key] }
                }),
                {}
            );
        const newKeys = { "addPairs": `addPairs_${item.exchange}`, "manageOverrides": `manageOverrides_${item.exchange}`, "removePairs": `removePairs_${item.exchange}` };
        const modifiedAutoconfig = renameKeys(newKeys, modifiedAutoconfigTemplate);

        Object.keys(modifiedAutoconfig).forEach((element) => {
            job = modifiedAutoconfig[element];
            job.pairs.exclude = item.pairExcludes;
            job.pairs.include = item.pairIncludes;
            job.pairs.exchange = item.exchange;

            if (item.compounding) {
                if (element.includes("addPairs")) {
                    job.overrides.MAX_PAIR_PER_BASE = item.maxPairPerBase;
                    job.pairs.maxPairs = maxPairs.replace('maxPairCount=4', `maxPairCount=${item.maxPairPerBase * item.baseCurrencies.length}`);
                    job.filters.GotFreeSlots.target = checkFreeSlots
                    
                    if (item.exchange === "huobi") {
                        delete job.filters.spread;
                    }
                    
                } else if (element.includes("manageOverrides") && !item.manualPairs) {
                    job.setPairVariable.newOverrides = handleOverrides;
                    job.overrides.STOP_AFTER_SELL = deactivateWorstPair;
                    job.overrides.RANKING_RESULT = rankNewPairs;
                    job.overrides.VOLATILITY_MODE = setVolatilityMode;
                    job.overrides.PULLBACK_MODE = setPullbackMode;
                    job.overrides.TA_MODE = setTaMode;
                    job.overrides.DYNAMIC_SL = setDynamicSL;
                    job.overrides.USE_TLR = setUseTlr;
                    job.overrides.CUSTOM_TRADING_RANGE_MODE = setCustomTradingRangeMode;
                    job.overrides.TRADING_RANGE_LOW = setCustomRangeLow;
                    job.overrides.TRADING_RANGE_HIGH = setCustomRangeHigh;
                    job.overrides.REMOVE = dontLetLastPairBeRemoved
                    job.overrides.TOTAL_BASE_VALUE = totalBaseBalance;
                } else if (element.includes("manageOverrides") && item.manualPairs) {
                    job.setPairVariable.newOverrides = handleOverrides;
                    job.overrides.TOTAL_BASE_VALUE = totalBaseBalance;
                }
                else if (element.includes('removePairs')) {
                    job.filters.lastPair.target = dontLetLastPairBeRemoved
                    job.filters2.lastPair.target = dontLetLastPairBeRemoved
                    job.filters3.lastPair.target = dontLetLastPairBeRemoved
                }
            }

        });

        fs.writeFileSync(dir + "/config.js", JSON.stringify(modifiedConfig, null, 4));
        if (item.exchange !== 'binanceus') {
            fs.writeFileSync(dir + "/autoconfig.json", JSON.stringify(modifiedAutoconfig, null, 4).replace(/binance/g, item.exchange).replace(mvtsDefault, compatibleMvts));
        }
        else {
            fs.writeFileSync(dir + "/autoconfig.json", JSON.stringify(modifiedAutoconfig, null, 4).replace(/binanceus/g, 'binance').replace(/binance/g, item.exchange).replace(mvtsDefault, compatibleMvts));
        }
        console.log('config preset saved to:', dir)

    });

    console.log('Done. Get your configs in the build folder.')
})();
