// most code is just needed to make sure this only works when all relevant pairs have cycled
(function rankNewPairs(data) {
	// function ranks all pairs with status 'new', return value is compared to number of free slots in the handleOverrides function
	const base = data.pairName.split('-')[0];
	let configSameBasePairCount = 0;
	let sameBasePairs = [];
	let maxSameBase = 0;
	
	Object.keys(data.config.pairs.binance).forEach((pair => {
		if (pair.split('-')[0] === base) {
			configSameBasePairCount++;
			sameBasePairs.push(pair)
		}
		if (maxSameBase === 0) {
            maxSameBase = parseFloat(data.config.pairs.binance[pair].override.MAX_PAIR_PER_BASE)
        }
	}));
	let positionSameBase = [];
	let ratiosToRank = [];
	let newPairCount = [];
	let activePairCount = 0;
	sameBasePairs.forEach((pair => {
		if (data.config.pairs?.binance?.[pair]?.override?.STATUS === 'active' || data.pairVariables.binance?.[pair]?.newOverrides?.STATUS === 'active') {
                activePairCount++;
            }
		if (Object.keys(data.pairVariables.binance).indexOf(pair) > -1) {
			if (parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.BAG_SIZE) > 0) {
				positionSameBase.push(parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.BAG_SIZE));
			} else if (data.pairVariables.binance?.[pair]?.newOverrides?.BAG_SIZE === 'none') {
				positionSameBase.push(0);
			}
			if (data.pairVariables.binance?.[pair]?.newOverrides?.STATUS === 'new') {
				newPairCount.push(pair);

                // collect ranking data saved by handleOverrides function
				if (parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.RANKING_RATIO) > -1) {
					ratiosToRank.push(parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.RANKING_RATIO));
				}
			}
		}
	}));

	// failsafe, should prevent cases where a pair gets ranked again very shortly after others got activated but haven't traded yet
	if (activePairCount >= maxSameBase){
		return -1
	}

	let bullishPairRatios = []
	sameBasePairs.forEach((pair => {
		if (Object.keys(data.pairVariables.binance).indexOf(pair) > -1) {
			
			if (data.pairVariables.binance?.[pair]?.newOverrides?.STATUS === 'new') {

				if (parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.RANKING_RATIO) > -1 && data.pairVariables.binance?.[pair]?.newOverrides?.VERY_BULLISH) {
					bullishPairRatios.push(parseFloat(data.pairVariables.binance?.[pair]?.newOverrides?.RANKING_RATIO));
				}
			}
		}
	}));

	// sort wick/candle ratios
	const rankedRatios = ratiosToRank.sort(function (a, b) {
		return b - a;
	});
	const rankedBullishRatios = bullishPairRatios.sort(function (a, b) {
		return b - a;
	});
	// prioritize pairs that match bullish criteria for high tl trading
	const finalRanking = [...rankedBullishRatios, ...rankedRatios]

	// match pairs to ranks, keeping only unique values
	let rankIndexList = {}
	sameBasePairs.forEach((pair => {
		const rankIndex = finalRanking.indexOf(parseFloat(data.pairVariables?.binance?.[pair]?.newOverrides?.RANKING_RATIO));
		if (rankIndex < 0){
			// do nothing
		}
		else {
			rankIndexList[pair] = rankIndex + 1
		}
	}));

	const ranksWithoutDuplicates = [...new Set(Object.values(rankIndexList))];

	let result = {}
	ranksWithoutDuplicates.forEach((rank => {
		const pairName = Object.keys(rankIndexList)[Object.values(rankIndexList).indexOf(rank)];
		result[pairName] = rank
	}));

	// only return rank when all pairs of same base have cycled and generated data
	if (positionSameBase.length === configSameBasePairCount && newPairCount.length === ratiosToRank.length && newPairCount.length > 0 && Object.keys(result).length > 0 && data.pairVariables.binance?.[data.pairName]?.newOverrides?.STATUS === 'new' && data.pairVariables.binance?.[data.pairName]?.newOverrides?.RANKING_RESULT !== -2) {
        // return pair rank, set -2 when no rank exists
		return result?.[data.pairName] || -2;
	} 
	else {
		return -1;
	}
})(this)